@@ -116,14 +116,14 @@ def parse(
                 ignores.append(pattern)
     if show_all:
         return None
-    preds: list[Callable] = []
+    predicate_mime: Optional[Callable] = None
     if check_mimetype and (mimetype_shows or mimetype_ignores):
-        def predicate(path: str, /):
+        def predicate_mime(path: str, /):
             if path.endswith("/"):
                 return False
             mime = guess_type(path)[0] or "application/octet-stream"
             return not any(p(mime) for p in mimetype_shows) and any(p(mime) for p in mimetype_ignores)
-        preds.append(predicate)
+    preds: list[Callable] = []
     flags = IGNORECASE if ignore_case else 0
     if shows:
         show = re_compile("|".join(map(translate, shows)), flags).search
@@ -133,12 +133,16 @@ def parse(
     elif ignores:
         ignore = re_compile("|".join(map(translate, ignores)), flags).search
         preds.append(lambda path, /: ignore(path) is not None)
+    predicate_ignore: Optional[Callable] = None
     if not preds:
-        return None
+        return predicate_mime
     elif len(preds) == 1:
-        return preds[0]
+        predicate_ignore = preds[0]
     else:
-        return lambda path: all(p(path) for p in preds)
+        predicate_ignore = lambda path: all(p(path) for p in preds)
+    if predicate_mime is None:
+        return predicate_ignore
+    return lambda path: predicate_mime(path) or predicate_ignore(path)
 
 
 def read_file(file: bytes | str | PathLike | TextIO, /) -> list[str]:
